/*********************************************************************

           Software Adoption, Employment Composition 
	   and the Skill Content of Occupations 
	   in Chilean Firms  


This do-file: Generates tasks measures

*********************************************************************/

* Autor & Handel (2013) methodology
use "C:\Users\maria\Dropbox\Trabajo\Skills Tasks & Technology\Submissions\JDS submission\Re-submission\Version re-submitted\databases and dofiles\prgchlp1.dta", clear

* Weighting factors
gen pondera=spfwt80

* Edad (16-65)
gen edad=age_r

/* C_Q01a: In the last week, did you do any PAID work for at least one hour, either as an employee or as self-employed? 
   C_Q01b: Last week, were you away from a job or business that you plan to return to? 
   C_Q01c: Last week, did you do any UNPAID work for at least one hour for a business that you own or a relative owns? */
ren c_q01a aux
gen c_q01a=real(aux)
drop aux 

ren c_q01b aux
gen c_q01b=real(aux)
drop aux 

ren c_q01c aux
gen c_q01c=real(aux)
drop aux 

gen ocupado=1 if c_q01a==1
replace ocupado=0 if c_q01a==2
replace ocupado=1 if (c_q01a==2 & c_q01b==1) | (c_q01a==2 & c_q01c==1)

/* D_Q03: In which sector of the economy do you work? Is it...
	1=The private sector (for example a company)
	2=The public sector (for example the local government or a state school)
	3=A non-profit organisation (for example a charity, professional association or religious organisation) */
ren d_q03 aux
gen d_q03=real(aux)
drop aux 

/* D_Q04: In this job, are you working as an employee or are you selfemployed? 
	1=Employee
	2=Self-employed*/
ren d_q04 aux
gen d_q04=real(aux)
drop aux 

/* Ocupacion: 
isco08_c: Clasificacion de ocupaciones ISCO 2008  */
replace isco08_c=. if isco08_c==9996 | isco08_c==9997 | isco08_c==9998 | isco08_c==9999 
gen aux=isco08_c/1000
gen aux2=int(aux)
gen categ_ocup=1 if aux2==1
replace categ_ocup=3 if aux2==2
replace categ_ocup=3 if aux2==3
replace categ_ocup=2 if aux2==4
replace categ_ocup=4 if aux2==5
replace categ_ocup=4 if aux2>=6 & aux2<=9
drop if categ_ocup==.
label var categ_ocup "Occupational category"
label define categ_ocup 1 "Managers" 2 "Administrative workers" 3 "Production workers - Skilled" 4 "Production workers - Unskilled"
label values categ_ocup categ_ocup

* Sector de actividad:
/* isic1c: Sector a 1 digitos de la clasificacion ISIC - Rev4
	A=Agriculture, forestry and fishing 
	B=Mining and quarrying 
	C=Manufacturing 
	D=Electricity, gas, steam and air conditioning supply 
	E=Water supply; sewerage, waste management and remediation activities 
	F=Construction 
	G=Wholesale and retail trade; repair of motor vehicles and motorcycles 
	H=Transportation and storage 
	I=Accommodation and food service activities 
	J=Information and communication 
	K=Financial and insurance activities 
	L=Real estate activities 
	M=Professional, scientific and technical activities 
	N=Administrative and support service activities 
	O=Public administration and defence; compulsory social security --> No incluyo este sector
	P=Education 
	Q=Human health and social work activities 
	R=Arts, entertainment and recreation 
	S=Other service activities 
	T=Activities of households as employers; undifferentiated goods- and services-producing activities of households for own use 
	U=Activities of extraterritorial organizations and bodies */
gen sector_gr=1 if isic1c=="A" | isic1c=="B"
replace sector_gr=2 if isic1c=="C"
replace sector_gr=3 if isic1c=="D" | isic1c=="E" | isic1c=="F" | isic1c=="G" | isic1c=="H" | isic1c=="I" | isic1c=="J" | isic1c=="K" | isic1c=="L" | isic1c=="M" | isic1c=="N" | isic1c=="P" | isic1c=="Q" | isic1c=="R" | isic1c=="S" | isic1c=="T" | isic1c=="U"

gen sample=1 if (edad>=25 & edad<=65) & (ocupado==1) & (d_q03==1) & (d_q04==1) & (isic4_c<=9900) & (sector_gr>=1 & sector_gr<=3) & categ_ocup!=.
keep if sample==1
ta sample

* Identifica categorias ocupacionales
capture drop aux*
sort categ_ocup
gen aux1=_n
egen aux2=min(aux1), by(categ_ocup)
gen aux3=aux2-aux1
gen id_ocup=1 if aux3==0
drop aux*

* Identifica categorias ocupacionales y sectores
capture drop aux*
sort categ_ocup sector_gr
gen aux1=_n
egen aux2=min(aux1), by(categ_ocup sector_gr)
gen aux3=aux2-aux1
gen id_ocup_sec=1 if aux3==0
drop aux*

* ABSTRACT TASKS

/* (1) Reading material
*Lenght of document typically read 
In your ^JobLastjob, how often ^DoDid you usually ...
G_Q01a: read directions or instructions?  
G_Q01b: read letters, memos or e-mails?
G_Q01c: read articles in newspapers, magazines or newsletters?
G_Q01d: read articles in professional journals or scholarly publications?
G_Q01e: read book?
G_Q01f: manuals or reference material?
G_Q01g: read bills, invoices, bank statements or other financial statements?
G_Q01h: read diagrams, maps or schematics?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */

loc vars a b c d e f g h
foreach v of local vars {
	ren g_q01`v' aux`v' 
	gen g_q01`v'=real(aux`v')
	drop aux`v'
	replace g_q01`v'=. if g_q01`v'>5 | g_q01`v'==0
	}

egen suma=rowtotal(g_q01a g_q01b g_q01c g_q01d g_q01e g_q01f g_q01g g_q01h)

gen reading=1 if suma>=1 & suma<=8
replace reading=2 if suma>=9 & suma<=16
replace reading=3 if suma>=17 & suma<=27
replace reading=4 if suma>=28 & suma<=32
replace reading=5 if suma>=33 & suma<=40
drop suma

/* (2) Frequency of math tasks involving at least high school mathematics 
In your ^JobLastjob, how often ^DoDid you usually 
G_Q03b: calculate prices, costs or budgets?
G_Q03c: use or calculate fractions, decimals or percentages?
G_Q03d: use a calculator - either hand-held or computer based?
G_Q03f: prepare charts, graphs or tables?
G_Q03g: use simple algebra or formulas?
G_Q03h: use more advanced math or statistics such as calculus, complex algebra, trigonometry or use of regression techniques?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */

loc vars b c d f g h
foreach v of local vars {
	ren g_q03`v' aux`v' 
	gen g_q03`v'=real(aux`v')
	drop aux`v'
	replace g_q03`v'=. if g_q03`v'>5 | g_q03`v'==0
	}

egen suma=rowtotal(g_q03b g_q03c g_q03d g_q03f g_q03g g_q03h) 

gen math=1 if suma>=1 & suma<=6
replace math=2 if suma>=7 & suma<=12
replace math=3 if suma>=13 & suma<=18
replace math=4 if suma>=19 & suma<=24
replace math=5 if suma>=25 & suma<=30
drop suma

/* (3) Frequency of problem solving tasks requiring at least 30 minutes to be solved 
F_Q05b: And how often ^AreWere you usually confronted with more complex problems that ^TakeTook at least 30 minutes to find a good solution?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
ren f_q05b aux
gen f_q05b=real(aux)
drop aux
replace f_q05b=. if f_q05b>5
gen probl_solv=f_q05b

/* (4) Supervising other workers
D_Q08a: Do you manage or supervise other employees?
	1=Yes
	2=No */
ren d_q08a aux
gen d_q08a=real(aux)
drop aux
replace d_q08a=. if d_q08a>2
replace d_q08a=0 if d_q08a==2
gen supervising=d_q08a

/* (5) Writing
Longest documetn written at work
In your ^JobLastjob, how often ^DoDid you usually 
G_Q02a: write letters, memos or e-mails?
G_Q02b: write articles for newspapers, magazines or newsletters? 
G_Q02c: write reports?
G_Q02d: fill in forms?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */

loc vars a b c d
foreach v of local vars {
	ren g_q02`v' aux`v'
	gen g_q02`v'=real(aux`v')
	drop aux`v'
	replace g_q02`v'=. if g_q02`v'>5 | g_q02`v'==0
	}

egen suma=rowtotal(g_q02a g_q02b g_q02c g_q02d)

gen writing=1 if suma>=1 & suma<=4
replace writing=2 if suma>=5 & suma<=8
replace writing=3 if suma>=9 & suma<=12
replace writing=4 if suma>=13 & suma<=16
replace writing=5 if suma>=17 & suma<=20
drop suma

/* (6) Learning at work
D_Q13a: In your own job, how often do you learn new work-related things from co-workers or supervisors?	
D_Q13b: How often does your job involve learning-by-doing from the tasks you perform?
D_Q13c: How often does your job involve keeping up to date with new products or services?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */

loc vars a b c 
foreach v of local vars {
	ren d_q13`v' aux`v'
	gen d_q13`v'=real(aux`v')
	drop aux`v'
	replace d_q13`v'=. if d_q13`v'>5 | d_q13`v'==0
	}

egen suma=rowtotal(d_q13a d_q13b d_q13c)

gen learning=1 if suma>=1 & suma<=3
replace learning=2 if suma>=4 & suma<=6
replace learning=3 if suma>=7 & suma<=9
replace learning=4 if suma>=10 & suma<=12
replace learning=5 if suma>=13 & suma<=15
drop suma

/* (7) Presentation
F_Q02c: How often ^DoesDid your ^JobLastjob usually involve making speeches or giving presentations in front of five or more people?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
ren f_q02c aux
gen f_q02c=real(aux)
drop aux 
replace f_q02c=. if f_q02c>5
gen presentations=f_q02c

/* (8) Interaction with other people
How often ^DoesDid your ^JobLastjob usually involve...
F_Q02a: sharing work-related information with co-workers?
F_Q02b: instructing, training or teaching people, individually or in groups?
F_Q02d: selling a product or selling a service?
F_Q02e: advising people?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
loc vars a b d e 
foreach v of local vars {
	ren f_q02`v' aux`v'
	gen f_q02`v'=real(aux`v')
	drop aux`v'
	replace f_q02`v'=. if f_q02`v'>5 | f_q02`v'==0
	}

egen suma=rowtotal(f_q02a f_q02b f_q02d f_q02e)

gen interaction=1 if suma>=1 & suma<=4
replace interaction=2 if suma>=5 & suma<=8
replace interaction=3 if suma>=9 & suma<=12
replace interaction=4 if suma>=13 & suma<=16
replace interaction=5 if suma>=17 & suma<=20
drop suma

* ROUTINE-COGNITIVE TASKS

/* (1) Autonomy (structures vs unstructured work)
D_Q11a/b/c/d: To what extent can you choose or change the sequence of your tasks/how you do your work/the speed or rate at which you work/your working hours?
	1=Not at all
	2=Very little
	3=To some extent
	4=To a high extent
	5=To a very high extent */
loc vars a b c d 
foreach v of local vars {
	ren d_q11`v' aux`v'
	gen d_q11`v'=real(aux`v')
	drop aux`v'
	replace d_q11`v'=. if d_q11`v'>5 | d_q11`v'==0
	}

egen suma=rowtotal(d_q11a d_q11b d_q11c d_q11d)

gen structure=5 if suma>=1 & suma<=4
replace structure=4 if suma>=5 & suma<=8
replace structure=3 if suma>=9 & suma<=12
replace structure=2 if suma>=13 & suma<=16
replace structure=1 if suma>=17 & suma<=20

* MANUAL TASKS (ROUTINE & NON-ROUTINE)

/* (1) F_Q06c: How often ^DoesDid your ^JobLastjob usually involve using skill or accuracy with your hands or fingers? 
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
ren f_q06c aux
gen f_q06c=real(aux)
drop aux 
replace f_q06c=. if f_q06c>5 | f_q06c==0
gen accuracy=f_q06c

/* (2) Phisically demanding job
F_Q06b: How often ^DoesDid your ^JobLastjob usually involve working physically for a long period? 
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
ren f_q06b aux
gen f_q06b=real(aux)
drop aux 
replace f_q06b=. if f_q06b>5
gen physical=f_q06b

*********************************************************************

* PCA - Abstract tasks
mat obs_ocup=J(4,3,.)

* a) Ocupaciones
pca reading math supervising writing interaction presentation probl_solv learning [w=pondera]

* Generates individual scores
rotate
predict comp1_abstract_ind 

gen abst_ocup=.
forvalues c=1/4 {
	qui sum comp1_abstract_ind if categ_ocup==`c' [w=pondera]
	replace abst_ocup=r(mean) if categ_ocup==`c'
		}

gen abst_ocup_sec=.
forvalues c=1/4 {
	forvalues s=1/3 {
		qui sum comp1_abstract_ind if categ_ocup==`c' & sector_gr==`s' [w=pondera]
		replace abst_ocup_sec=r(mean) if categ_ocup==`c' & sector_gr==`s'
			}
		}

* PCA - Routine-cognitive tasks

* a) Ocupaciones
sum structure [w=pondera]
loc mu=r(mean)
loc sd=r(sd)
gen structure_aux=(structure - `mu')/`sd'

gen rout_cog_ocup=.
forvalues c=1/4 {
	qui sum structure_aux if categ_ocup==`c' [w=pondera]
	replace rout_cog_ocup=r(mean) if categ_ocup==`c'
		}

gen rout_cog_ocup_sec=.
forvalues c=1/4 {
	forvalues s=1/3 {
		qui sum structure_aux if categ_ocup==`c' & sector_gr==`s' [w=pondera]
		replace rout_cog_ocup_sec=r(mean) if categ_ocup==`c' & sector_gr==`s' 
			}
		}

* PCA - Manual tasks

* a) Ocupaciones
pca physical accuracy [w=pondera]

* Generates individual scores
rotate
predict comp1_manual_ind 

gen manual_ocup=.
forvalues c=1/4 {
	qui sum comp1_manual_ind if categ_ocup==`c' [w=pondera]
	replace manual_ocup=r(mean) if categ_ocup==`c'
		}

gen manual_ocup_sec=.
forvalues c=1/4 {
	forvalues s=1/3 {
		qui sum comp1_manual_ind if categ_ocup==`c' & sector_gr==`s' [w=pondera]
		replace manual_ocup_sec=r(mean) if categ_ocup==`c' & sector_gr==`s'
			}
		}

* Task Content Measures based on the PIAAC Survey by Occupation in ELE Following Methodology of Autor and Handel (2013): Table 5 in online Supplementary Materials
table categ_ocup, c(mean abst_ocup mean rout_cog_ocup mean manual_ocup)

*********************************************************************

* Acemoglu & Autor (2011) methodology
use "C:\Users\maria\Dropbox\Trabajo\Skills Tasks & Technology\Submissions\JDS submission\Re-submission\Version re-submitted\databases and dofiles\prgchlp1.dta", clear

* Weighting factors
gen pondera=spfwt80

* Edad (16-65)
gen edad=age_r

/* C_Q01a: In the last week, did you do any PAID work for at least one hour, either as an employee or as self-employed? 
   C_Q01b: Last week, were you away from a job or business that you plan to return to? 
   C_Q01c: Last week, did you do any UNPAID work for at least one hour for a business that you own or a relative owns? */
ren c_q01a aux
gen c_q01a=real(aux)
drop aux 

ren c_q01b aux
gen c_q01b=real(aux)
drop aux 

ren c_q01c aux
gen c_q01c=real(aux)
drop aux 

gen ocupado=1 if c_q01a==1
replace ocupado=0 if c_q01a==2
replace ocupado=1 if (c_q01a==2 & c_q01b==1) | (c_q01a==2 & c_q01c==1)

/* D_Q03: In which sector of the economy do you work? Is it...
	1=The private sector (for example a company)
	2=The public sector (for example the local government or a state school)
	3=A non-profit organisation (for example a charity, professional association or religious organisation) */
ren d_q03 aux
gen d_q03=real(aux)
drop aux 

/* D_Q04: In this job, are you working as an employee or are you selfemployed? 
	1=Employee
	2=Self-employed*/
ren d_q04 aux
gen d_q04=real(aux)
drop aux 

/* Ocupacion: 
isco08_c: Clasificacion de ocupaciones ISCO 2008  */
replace isco08_c=. if isco08_c==9996 | isco08_c==9997 | isco08_c==9998 | isco08_c==9999 
gen aux=isco08_c/1000
gen categ_ocup_1d=int(aux)
replace categ_ocup_1d=. if categ_ocup_1d==0

gen categ_ocup_ele=1 if categ_ocup_1d==1
replace categ_ocup_ele=3 if categ_ocup_1d==2
replace categ_ocup_ele=3 if categ_ocup_1d==3
replace categ_ocup_ele=2 if categ_ocup_1d==4
replace categ_ocup_ele=4 if categ_ocup_1d==5
replace categ_ocup_ele=4 if categ_ocup_1d>=6 & categ_ocup_1d<=9
drop if categ_ocup_ele==.
label var categ_ocup_ele "Occupational category"
label define categ_ocup_ele 1 "Managers" 2 "Administrative workers" 3 "Production workers - Skilled" 4 "Production workers - Unskilled"
label values categ_ocup_ele categ_ocup_ele
drop aux*

* Sector de actividad:
/* isic1c: Sector a 1 digitos de la clasificacion ISIC - Rev4
	A=Agriculture, forestry and fishing 
	B=Mining and quarrying 
	C=Manufacturing 
	D=Electricity, gas, steam and air conditioning supply 
	E=Water supply; sewerage, waste management and remediation activities 
	F=Construction 
	G=Wholesale and retail trade; repair of motor vehicles and motorcycles 
	H=Transportation and storage 
	I=Accommodation and food service activities 
	J=Information and communication 
	K=Financial and insurance activities 
	L=Real estate activities 
	M=Professional, scientific and technical activities 
	N=Administrative and support service activities 
	O=Public administration and defence; compulsory social security --> No incluyo este sector
	P=Education 
	Q=Human health and social work activities 
	R=Arts, entertainment and recreation 
	S=Other service activities 
	T=Activities of households as employers; undifferentiated goods- and services-producing activities of households for own use 
	U=Activities of extraterritorial organizations and bodies */
gen sector_gr=1 if isic1c=="A" | isic1c=="B"
replace sector_gr=2 if isic1c=="C"
replace sector_gr=3 if isic1c=="D" | isic1c=="E" | isic1c=="F" | isic1c=="G" | isic1c=="H" | isic1c=="I" | isic1c=="J" | isic1c=="K" | isic1c=="L" | isic1c=="M" | isic1c=="N" | isic1c=="P" | isic1c=="Q" | isic1c=="R" | isic1c=="S" | isic1c=="T" | isic1c=="U"

gen sample=1 if (edad>=25 & edad<=65) & (ocupado==1) & (d_q03==1) & (d_q04==1) & (isic4_c<=9900) & (sector_gr>=1 & sector_gr<=3) & categ_ocup_ele!=.
keep if sample==1
ta sample

* Identifica categorias ocupacionales
capture drop aux*
sort categ_ocup_ele
gen aux1=_n
egen aux2=min(aux1), by(categ_ocup_ele)
gen aux3=aux2-aux1
gen id_ocup=1 if aux3==0
drop aux*

* Identifica categorias ocupacionales y sector
capture drop aux*
sort categ_ocup_ele sector_gr
gen aux1=_n
egen aux2=min(aux1), by(categ_ocup_ele sector_gr)
gen aux3=aux2-aux1
gen id_ocup_sec=1 if aux3==0
drop aux*

* Ponderadores: Contribucion de cada ocupacion a las horas trabajadas la semana pasada
/* D_Q10: How many hours do you usually work per week in this job? Include any usual paid or unpaid overtime, but exclude lunch breaks or other breaks*/
ren d_q10 aux
gen d_q10=real(aux)

gen horas=.
forvalues o=1/9 {
	sum d_q10 [w=pondera] if categ_ocup_1d==`o'
	replace horas=r(mean) if categ_ocup_1d==`o'
	gen horas_`o'=r(mean) 
	}

egen horas_total=rowtotal(horas_1 horas_2 horas_3 horas_4 horas_5 horas_6 horas_7 horas_8 horas_9)

gen weight=horas/horas_total
drop horas_*
ta weight

* ABSTRACT TASKS

/* (1) Reading material
*Lenght of document typically read 
In your ^JobLastjob, how often ^DoDid you usually ...
G_Q01a: read directions or instructions?  
G_Q01b: read letters, memos or e-mails?
G_Q01c: read articles in newspapers, magazines or newsletters?
G_Q01d: read articles in professional journals or scholarly publications?
G_Q01e: read book?
G_Q01f: manuals or reference material?
G_Q01g: read bills, invoices, bank statements or other financial statements?
G_Q01h: read diagrams, maps or schematics?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
loc vars a b c d e f g h
foreach v of local vars {
	ren g_q01`v' aux`v' 
	gen g_q01`v'=real(aux`v')
	drop aux`v'
	replace g_q01`v'=. if g_q01`v'>5 | g_q01`v'==0
	}

egen suma=rowtotal(g_q01a g_q01b g_q01c g_q01d g_q01e g_q01f g_q01g g_q01h)

gen reading=1 if suma>=1 & suma<=8
replace reading=2 if suma>=9 & suma<=16
replace reading=3 if suma>=17 & suma<=27
replace reading=4 if suma>=28 & suma<=32
replace reading=5 if suma>=33 & suma<=40
drop suma

/* (2) Frequency of math tasks involving at least high school mathematics 
In your ^JobLastjob, how often ^DoDid you usually 
G_Q03b: calculate prices, costs or budgets?
G_Q03c: use or calculate fractions, decimals or percentages?
G_Q03d: use a calculator - either hand-held or computer based?
G_Q03f: prepare charts, graphs or tables?
G_Q03g: use simple algebra or formulas?
G_Q03h: use more advanced math or statistics such as calculus, complex algebra, trigonometry or use of regression techniques?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
loc vars b c d f g h
foreach v of local vars {
	ren g_q03`v' aux`v' 
	gen g_q03`v'=real(aux`v')
	drop aux`v'
	replace g_q03`v'=. if g_q03`v'>5 | g_q03`v'==0
	}

egen suma=rowtotal(g_q03b g_q03c g_q03d g_q03f g_q03g g_q03h) 

gen math=1 if suma>=1 & suma<=6
replace math=2 if suma>=7 & suma<=12
replace math=3 if suma>=13 & suma<=18
replace math=4 if suma>=19 & suma<=24
replace math=5 if suma>=25 & suma<=30
drop suma

/* (3) Frequency of problem solving tasks requiring at least 30 minutes to be solved 
F_Q05b: And how often ^AreWere you usually confronted with more complex problems that ^TakeTook at least 30 minutes to find a good solution?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */

capture drop aux*
ren f_q05b aux
gen f_q05b=real(aux)
drop aux
replace f_q05b=. if f_q05b>5
gen probl_solv=f_q05b

/* (4) Supervising other workers
D_Q08a: Do you manage or supervise other employees?
	1=Yes
	2=No */

capture drop aux*
ren d_q08a aux
gen d_q08a=real(aux)
drop aux
replace d_q08a=. if d_q08a>2
replace d_q08a=0 if d_q08a==2
gen supervising=d_q08a

/* (5) Writing
Longest documetn written at work
In your ^JobLastjob, how often ^DoDid you usually 
G_Q02a: write letters, memos or e-mails?
G_Q02b: write articles for newspapers, magazines or newsletters? 
G_Q02c: write reports?
G_Q02d: fill in forms?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
loc vars a b c d
foreach v of local vars {
	ren g_q02`v' aux`v'
	gen g_q02`v'=real(aux`v')
	drop aux`v'
	replace g_q02`v'=. if g_q02`v'>5 | g_q02`v'==0
	}

egen suma=rowtotal(g_q02a g_q02b g_q02c g_q02d)

gen writing=1 if suma>=1 & suma<=4
replace writing=2 if suma>=5 & suma<=8
replace writing=3 if suma>=9 & suma<=12
replace writing=4 if suma>=13 & suma<=16
replace writing=5 if suma>=17 & suma<=20
drop suma

/* (6) Learning at work
D_Q13a: In your own job, how often do you learn new work-related things from co-workers or supervisors?	
D_Q13b: How often does your job involve learning-by-doing from the tasks you perform?
D_Q13c: How often does your job involve keeping up to date with new products or services?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
loc vars a b c 
foreach v of local vars {
	ren d_q13`v' aux`v'
	gen d_q13`v'=real(aux`v')
	drop aux`v'
	replace d_q13`v'=. if d_q13`v'>5 | d_q13`v'==0
	}

egen suma=rowtotal(d_q13a d_q13b d_q13c)

gen learning=1 if suma>=1 & suma<=3
replace learning=2 if suma>=4 & suma<=6
replace learning=3 if suma>=7 & suma<=9
replace learning=4 if suma>=10 & suma<=12
replace learning=5 if suma>=13 & suma<=15
drop suma

/* (7) Presentation
F_Q02c: How often ^DoesDid your ^JobLastjob usually involve making speeches or giving presentations in front of five or more people?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
ren f_q02c aux
gen f_q02c=real(aux)
drop aux 
replace f_q02c=. if f_q02c>5
gen presentations=f_q02c

/* (8) Interaction with other people
How often ^DoesDid your ^JobLastjob usually involve...
F_Q02a: sharing work-related information with co-workers?
F_Q02b: instructing, training or teaching people, individually or in groups?
F_Q02d: selling a product or selling a service?
F_Q02e: advising people?
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
loc vars a b d e 
foreach v of local vars {
	ren f_q02`v' aux`v'
	gen f_q02`v'=real(aux`v')
	drop aux`v'
	replace f_q02`v'=. if f_q02`v'>5 | f_q02`v'==0
	}

egen suma=rowtotal(f_q02a f_q02b f_q02d f_q02e)

gen interaction=1 if suma>=1 & suma<=4
replace interaction=2 if suma>=5 & suma<=8
replace interaction=3 if suma>=9 & suma<=12
replace interaction=4 if suma>=13 & suma<=16
replace interaction=5 if suma>=17 & suma<=20
drop suma

* ROUTINE-COGNITIVE TASKS

/* (1) Autonomy (structures vs unstructured work)
D_Q11a/b/c/d: To what extent can you choose or change the sequence of your tasks/how you do your work/the speed or rate at which you work/your working hours?
	1=Not at all
	2=Very little
	3=To some extent
	4=To a high extent
	5=To a very high extent */
capture drop aux*
loc vars a b c d 
foreach v of local vars {
	ren d_q11`v' aux`v'
	gen d_q11`v'=real(aux`v')
	drop aux`v'
	replace d_q11`v'=. if d_q11`v'>5 | d_q11`v'==0
	}

egen suma=rowtotal(d_q11a d_q11b d_q11c d_q11d)

gen structure=5 if suma>=1 & suma<=4
replace structure=4 if suma>=5 & suma<=8
replace structure=3 if suma>=9 & suma<=12
replace structure=2 if suma>=13 & suma<=16
replace structure=1 if suma>=17 & suma<=20

* MANUAL TASKS (ROUTINE & NON-ROUTINE)

/* (1) F_Q06c: How often ^DoesDid your ^JobLastjob usually involve using skill or accuracy with your hands or fingers? 
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
ren f_q06c aux
gen f_q06c=real(aux)
drop aux 
replace f_q06c=. if f_q06c>5 | f_q06c==0
gen accuracy=f_q06c

/* (2) Phisically demanding job
F_Q06b: How often ^DoesDid your ^JobLastjob usually involve working physically for a long period? 
	1=Never
	2=Less than once a month
	3=Less than once a week but at least once a month
	4=At least once a week but not every day
	5=Every day */
capture drop aux*
ren f_q06b aux
gen f_q06b=real(aux)
drop aux 
replace f_q06b=. if f_q06b>5
gen physical=f_q06b

*********************************************************************

* Paso 1: Estandariza variables en toda la muestra
loc variables = "reading math probl_solv supervising writing learning presentations interaction structure accuracy physical"

foreach var of local variables {
	sum `var' [w=pondera]
	loc mean=r(mean)
	loc sd=r(sd)
	gen `var'_st=(`var'-`mean')/`sd'
	}

* Paso 2: Suma los componentes correspondientes al mismo task
egen abstract=rowmean(reading_st math_st probl_solv_st supervising_st writing_st presentations_st interaction_st learning_st)
sum abstract [w=pondera]
loc mean=r(mean)
loc sd=r(sd)
gen abstract_aux=(abstract-`mean')/`sd'
replace abstract=abstract_aux

gen rout_cog=structure_st

egen manual=rowmean(accuracy_st physical_st)
sum manual [w=pondera]
loc mean=r(mean)
loc sd=r(sd)
gen manual_aux=(manual-`mean')/`sd'
replace manual=manual_aux

* Paso 3: Calcula el promedio para cada ocupacion ponderando por la contribucion de cada ocupacion a 1d a las horas trabajadas la semana pasada
gen abst_ocup_op2=.
gen rout_cog_ocup_op2=.
gen manual_ocup_op2=.

forvalues c=1/4 {
	sum abstract if categ_ocup_ele==`c' [w=weight]
	replace abst_ocup_op2=r(mean) if categ_ocup_ele==`c'

	sum rout_cog if categ_ocup_ele==`c' [w=weight]
	replace rout_cog_ocup_op2=r(mean) if categ_ocup_ele==`c'

	sum manual if categ_ocup_ele==`c' [w=weight]
	replace manual_ocup_op2=r(mean) if categ_ocup_ele==`c'
	}

gen abst_ocup_sec_op2=.
gen rout_cog_ocup_sec_op2=.
gen manual_ocup_sec_op2=.

forvalues c=1/4 {
	forvalues s=1/3 {
		sum abstract if categ_ocup_ele==`c' & sector_gr==`s' [w=weight]
		replace abst_ocup_sec_op2=r(mean) if categ_ocup_ele==`c' & sector_gr==`s'

		sum rout_cog if categ_ocup_ele==`c' & sector_gr==`s' [w=weight]
		replace rout_cog_ocup_sec_op2=r(mean) if categ_ocup_ele==`c' & sector_gr==`s'

		sum manual if categ_ocup_ele==`c' & sector_gr==`s' [w=weight]
		replace manual_ocup_sec_op2=r(mean) if categ_ocup_ele==`c' & sector_gr==`s'
			}
		}

* Paso 4: Estandariza a nivel de ocupaciones

* Task Content Measures based on the PIAAC Survey by Occupation in the ELE Survey: Table 1 in Main document
table categ_ocup_ele, c(mean abst_ocup_op2 mean rout_cog_ocup_op2 mean manual_ocup_op2)
* NOTE: The table in the document has one extra standardization across occupations

* Task Content Measures based on the PIAAC Survey by Occupation and Sector of Activity in ELE Following Methodology of Autor and Acemoglu (2011): Table 6 in online Supplementary Materials
table categ_ocup_ele if sector_gr==1, c(mean abst_ocup_sec_op2 mean rout_cog_ocup_sec_op2 mean manual_ocup_sec_op2)
table categ_ocup_ele if sector_gr==2, c(mean abst_ocup_sec_op2 mean rout_cog_ocup_sec_op2 mean manual_ocup_sec_op2)
table categ_ocup_ele if sector_gr==3, c(mean abst_ocup_sec_op2 mean rout_cog_ocup_sec_op2 mean manual_ocup_sec_op2)
* NOTE: The table in the document has one extra standardization across occupations

