/*********************************************************************

           Software Adoption, Employment Composition 
	   and the Skill Content of Occupations 
	   in Chilean Firms  


This do-file: Generates descriptive stats

*********************************************************************/

use "ele_2007_2013.dta", replace

xtset id_firma ano

* Sample for descriptive stats (same as in main regressions) 
xtivreg2 shr_cat1_v1 dano* (soft19=uso_comp_reg_ict) if sample==1 [w=fe_empresa], fe cl(grupo)
gen aux=1 if e(sample)
egen suma=sum(aux), by(id_firma)
gen muestra_stats=1 if suma==2 
drop aux

* Weights
gen aux=round(fe_empresa)
replace fe_empresa=aux
drop aux

gen ano_aux=1 if ano==2007
replace ano_aux=2 if ano==2013

keep if muestra_stats==1 & muestra_extremos==1

* Table 2: Sectoral and Size Composition of the ELE Panel Sample

* Distribution of observations by economic sector 
mat shr_sector=J(11,3,.)

forvalues a=1/2 {
	forvalues s=1/11 {
		sum fe_empresa if sector!=. & ano_aux==`a'
		loc total=r(sum)

		sum fe_empresa if sector==`s' & ano_aux==`a'
		loc sector=r(sum)
		mat shr_sector[`s',`a']=(`sector'/`total')*100
			}
		}

forvalues s=1/11 {
	mat shr_sector[`s',3]=(shr_sector[`s',1]+shr_sector[`s',2])/2
	}
mat list shr_sector
* NOTE: We report column 3

* Distribution of observations by firm size 
mat shr_tamano=J(4,3,.)

gen empleo_total_aux=empleo_cat1 + empleo_cat2 + empleo_cat3 + empleo_cat4
gen tamano_v2=1 if empleo_total_aux<=5
replace tamano_v2=2 if empleo_total_aux>5 & empleo_total_aux<=20
replace tamano_v2=3 if empleo_total_aux>20 & empleo_total_aux<=50
replace tamano_v2=4 if empleo_total_aux>50 & empleo_total_aux<.
drop empleo_total_aux

forvalues a=1/2 {
	forvalues t=1/4 {
		sum fe_empresa if tamano_v2!=. & ano_aux==`a'
		loc total=r(sum)

		sum fe_empresa if tamano_v2==`t' & ano_aux==`a'
		loc tamano=r(sum)
		mat shr_tamano[`t',`a']=(`tamano'/`total')*100
			}
		}

forvalues i=1/4 {
	mat shr_tamano[`i',3]=(shr_tamano[`i',1]+shr_tamano[`i',2])/2
	}
mat list shr_tamano
* NOTE: We report column 3

* Table 3: Summary Statistics on Employment-Related Outcome Variables, ICT Use Variables and Firm Characteristics
gen empleo_total_aux=empleo_cat1 + empleo_cat2 + empleo_cat3 + empleo_cat4 
gen empleo_cat1_shr=empleo_cat1/empleo_total_aux
gen empleo_cat2_shr=empleo_cat2/empleo_total_aux
gen empleo_cat3_shr=empleo_cat3/empleo_total_aux
gen empleo_cat4_shr=empleo_cat4/empleo_total_aux
drop empleo_total_aux

mat descriptive_stats=J(26,4,.)

loc c=0
forvalues a=1/2 {
*	Shares in total employment
	sum empleo_cat1_shr [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[1,1+`c'*2]=r(mean)
	mat descriptive_stats[1,2+`c'*2]=r(sd)

	sum empleo_cat2_shr [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[2,1+`c'*2]=r(mean)
	mat descriptive_stats[2,2+`c'*2]=r(sd)

	sum empleo_cat3_shr [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[3,1+`c'*2]=r(mean)
	mat descriptive_stats[3,2+`c'*2]=r(sd)

	sum empleo_cat4_shr [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[4,1+`c'*2]=r(mean)
	mat descriptive_stats[4,2+`c'*2]=r(sd)

*	Task measures
	sum index_abst_v1_op2 [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[6,1+`c'*2]=r(mean)
	mat descriptive_stats[6,2+`c'*2]=r(sd)

	sum index_rout_cog_v1_op2 [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[7,1+`c'*2]=r(mean)
	mat descriptive_stats[7,2+`c'*2]=r(sd)

	sum index_man_v1_op2 [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[8,1+`c'*2]=r(mean)
	mat descriptive_stats[8,2+`c'*2]=r(sd)

*	Training and outsourcing
	sum capacitacion [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[10,1+`c'*2]=r(mean)
	mat descriptive_stats[10,2+`c'*2]=r(sd)

	sum capac_manager [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[11,1+`c'*2]=r(mean)
	mat descriptive_stats[11,2+`c'*2]=r(sd)

	sum capac_manager_ict [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[12,1+`c'*2]=r(mean)
	mat descriptive_stats[12,2+`c'*2]=r(sd)

	sum subcontrato [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[13,1+`c'*2]=r(mean)
	mat descriptive_stats[13,2+`c'*2]=r(sd)

*	ICT use
	sum compu [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[15,1+`c'*2]=r(mean)
	mat descriptive_stats[15,2+`c'*2]=r(sd)

	sum internet [w=fe_empresa] if compu==1 & ano_aux==`a'
	mat descriptive_stats[16,1+`c'*2]=r(mean)
	mat descriptive_stats[16,2+`c'*2]=r(sd)

	sum soft19 [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[17,1+`c'*2]=r(mean)
	mat descriptive_stats[17,2+`c'*2]=r(sd)

*	Firms' characteristics
	sum edad_firma [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[19,1+`c'*2]=r(mean)
	mat descriptive_stats[19,2+`c'*2]=r(sd)

	sum exporta [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[20,1+`c'*2]=r(mean)
	mat descriptive_stats[20,2+`c'*2]=r(sd)

	sum foreign [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[21,1+`c'*2]=r(mean)
	mat descriptive_stats[21,2+`c'*2]=r(sd)

	sum credit_constraint [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[22,1+`c'*2]=r(mean)
	mat descriptive_stats[22,2+`c'*2]=r(sd)

	sum edad_manager [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[23,1+`c'*2]=r(mean)
	mat descriptive_stats[23,2+`c'*2]=r(sd)

	sum exper_manager [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[24,1+`c'*2]=r(mean)
	mat descriptive_stats[24,2+`c'*2]=r(sd)

	sum deduc_man2 [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[25,1+`c'*2]=r(mean)
	mat descriptive_stats[25,2+`c'*2]=r(sd)

	sum deduc_man3 [w=fe_empresa] if ano_aux==`a'
	mat descriptive_stats[26,1+`c'*2]=r(mean)
	mat descriptive_stats[26,2+`c'*2]=r(sd)
	
	loc c=`c'+1
	}

mat list descriptive_stats


* Switchers analysis: Table 1 in online Supplementary Materials

* Identifica switchers
gen aux07=soft19 if ano==2007
gen aux13=soft19 if ano==2013

egen min07=min(aux07), by(id_firma)
egen min13=min(aux13), by(id_firma)

capture drop change*
gen change1307=min13-min07
drop aux* min*

* # of switchers by firm size and by sector
gen switch1307=1 if change1307==-1 | change1307==1  
gen adopt1307=1 if change1307==1  
gen disadopt1307=1 if change1307==-1 

ta change1307 if ano==2007 & muestra_stats==1 & muestra_extremos==1
ta change1307 if ano==2013 & muestra_stats==1 & muestra_extremos==1

gen pondera_aux=fe_empresa if ano==2013 
egen min=min(pondera_aux), by(id_firma)
replace pondera_aux=min if ano==2007
drop min

* Column 1: Share of firms using complex software in 2007
table tamano_v2 [w=pondera_aux] if ano==2007 & muestra_stats==1 & muestra_extremos==1, c(mean soft19)
table sector_aux [w=pondera_aux] if ano==2007 & muestra_stats==1 & muestra_extremos==1, c(mean soft19)

* Column 2: Share of firms switching software use status
ta change1307 [w=pondera_aux] if ano==2013 & muestra_stats==1 & muestra_extremos==1
table tamano_v2 [w=pondera_aux] if ano==2013 & muestra_stats==1 & muestra_extremos==1, c(N switch1307)
table sector_aux [w=pondera_aux] if ano==2013 & muestra_stats==1 & muestra_extremos==1, c(N switch1307)

* Probit model: Table 4 in Main document 
capture drop empleo_total_aux 
capture drop tamano_v2 
gen empleo_total_aux=empleo_cat1 + empleo_cat2 + empleo_cat3 + empleo_cat4
gen tamano_v2=1 if empleo_total_aux<=5
replace tamano_v2=2 if empleo_total_aux>5 & empleo_total_aux<=20
replace tamano_v2=3 if empleo_total_aux>20 & empleo_total_aux<=50
replace tamano_v2=4 if empleo_total_aux>50 & empleo_total_aux<.
drop empleo_total_aux

gen edad_aux=edad_firma if ano==2013 
egen min=min(edad_aux), by(id_firma)
replace edad_firma=min-4 if ano==2009 & (id_panel==1 | id_panel==4)
replace edad_firma=min-6 if ano==2007 & (id_panel==1 | id_panel==3)
drop min edad_aux

gen edad_aux=edad_firma if ano==2009
egen min=min(edad_aux), by(id_firma)
replace edad_firma=min-2 if ano==2007 & (id_panel==2)
drop min edad_aux
capture drop ledad_firma
gen ledad_firma=log(edad_firma)

capture drop dreg* dsec* dtam*
ta region, g(dreg)
ta sector_aux, g(dsec)
ta tamano_v2, g(dtam)

gen man_age=1 if edad_manager<50
replace man_age=0 if edad_manager>=50

gen man_exp=1 if exper_manager>10
replace man_exp=0 if exper_manager<=10

probit soft19 dtam2-dtam4 dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 ledad_firma dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 export dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 foreign dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 credit_constraint dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 man_age dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 man_exp dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 deduc_man2 deduc_man3 dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], robust
probit soft19 dtam2-dtam4 ledad_firma exporta foreign credit_constraint man_age man_exp deduc_man2 deduc_man3 dano1 dsec2-dsec11 dreg1-dreg12 dreg14-dreg15 [w=fe_empresa], 

* Summary Statistics on Regional Variables from CASEN: Table 3 in online Supplementary Materials
mat casen=J(15,4,.)

* 2006
use "casen2006.dta", clear

* Region
/* Variable region en la encuesta CASEN:
    1 = arica y parinacota   6 = valparaso                           11 = los ros
    2 = tarapac             7 = libertador general bernardo ohiggi  12 = los lagos  
    3 = antofagasta          8 = maule                                13 = aysn del general carlos ibaez del  
    4 = atacama              9 = bo bo                              14 = magallanes y de la antrtica chile 
    5 = coquimbo             10 = la araucana                        15 = regin metropolitana de santiago

   Variable region en la encuesta ELE:
    1 "Tarapac" 2 "Antofagasta" 3 "Atacama" 4 "Coquimbo" 5 "Valparaso" 6 "O'Higgins" 7 "Del Maule" 8 "BioBo" 9 "Araucana" 10 "Los Lagos" 11 "Aysn" 12 "Magallanes y Antrtica" 13 "Regin Metropolitana" 14 "Los Ros" 15 "Arica y Parinacota" */

capture drop region 
gen region=1 if reg_r_15==2
replace region=2 if reg_r_15==3
replace region=3 if reg_r_15==4
replace region=4 if reg_r_15==5
replace region=5 if reg_r_15==6
replace region=6 if reg_r_15==7
replace region=7 if reg_r_15==8
replace region=8 if reg_r_15==9
replace region=9 if reg_r_15==10
replace region=10 if reg_r_15==12
replace region=11 if reg_r_15==13
replace region=12 if reg_r_15==14
replace region=13 if reg_r_15==15
replace region=14 if reg_r_15==11
replace region=15 if reg_r_15==1
label var region "Regin geogrfica"
label define region 1 "Tarapac" 2 "Antofagasta" 3 "Atacama" 4 "Coquimbo" 5 "Valparaso" 6 "O'Higgins" 7 "Del Maule" 8 "BioBo" 9 "Araucana" 10 "Los Lagos" 11 "Aysn" 12 "Magallanes y Antrtica" 13 "Regin Metropolitana" 14 "Los Ros" 15 "Arica y Parinacota"
label values region region

forvalues r=1/15 {
	sum compu [w=pondera] if jefe==1 & region==`r'
	mat casen[`r',1]=r(mean)*100

	sum celular [w=pondera] if jefe==1 & region==`r'
	mat casen[`r',2]=r(mean)*100
	}


* 2013
use "casen2013.dta", clear

* Region
/* Variable region en la encuesta CASEN:
    1 = i: tarapac       6 = vi: libertador general bernardo ohiggi   11 = xi: aysn del general carlos ibaez del 
    2 = ii: antofagasta   7 = vii: maule                                12 = xii: magallanes y de la antrtica chile
    3 = iii: atacama      8 = viii: bo bo                             13 = r.m.: regin metropolitana de santiago
    4 = iv: coquimbo      9 = ix: la araucana                          14 = xiv: los ros
    5 = v: valparaso    10 = x: los lagos                              15 = xv: arica y parinacota */

capture drop region
ren reg_region region
label var region "Regin geogrfica"
label define region 1 "Tarapac" 2 "Antofagasta" 3 "Atacama" 4 "Coquimbo" 5 "Valparaso" 6 "O'Higgins" 7 "Del Maule" 8 "BioBo" 9 "Araucana" 10 "Los Lagos" 11 "Aysn" 12 "Magallanes y Antrtica" 13 "Regin Metropolitana" 14 "Los Ros" 15 "Arica y Parinacota"
label values region region

forvalues r=1/15 {
	sum compu [w=pondera] if jefe==1 & region==`r'
	mat casen[`r',3]=r(mean)*100

	sum celular [w=pondera] if jefe==1 & region==`r'
	mat casen[`r',4]=r(mean)*100
	}

mat list casen

